@@ -3,7 +3,7 @@ package WWW::Tumblr;
 use strict;
 use warnings;
 
-our $VERSION = '5.00';
+our $VERSION = '5.00_01';
 
 =pod
 
@@ -13,7 +13,7 @@ WWW::Tumblr - Perl bindings for the Tumblr API
 
 =head1 VERSION
 
-5.00
+5.00_01 (experimental release)
 
 =head1 SYNOPSIS
 
@@ -28,7 +28,7 @@ WWW::Tumblr - Perl bindings for the Tumblr API
 
   print Dumper $blog->info;
 
-=head1 DESCRIPTION
+head1 DESCRIPTION
 
 This module makes use of some sort of the same models as the upstream API,
 meaning that you will have User, Blog and Tagged methods:
@@ -128,6 +128,8 @@ This module supports Tumblr API v2, starting from module version 5. Since the
 previous API was deprecated upstream anyway, there's no backwards compatibility
 with < 5 versions.
 
+=
+
 =head1 AUTHOR(S)
 
 L<David Moreno|http://damog.net/> is the main author and maintainer of this module.
@@ -158,9 +160,8 @@ the same terms as the Perl 5 programming language system itself.
 =head1 DISCLAIMER
 
 The author is in no way affiliated to Tumblr or Yahoo! Inc. If either of them
-want to show their appreciation for this work, they can contact the author directly
-or donate a few of those billion dollars Yahoo! paid for Tumblr, to the Perl
-Foundation at L<http://donate.perlfoundation.org/>.
+want to show their appreciation for this work, they contact the author directly
+or donate to the Perl Foundation at L<http://donate.perlfoundation.org/>.
 
 =cut
 
